@@ -1,6 +1,5 @@
 use crate::traits::Protectable;
 
-use std::default::Default;
 use std::fmt;
 use std::ops::{Deref, DerefMut, Index, IndexMut, Drop};
 use std::sync::atomic::{AtomicUsize, Ordering};
@@ -90,15 +89,15 @@ impl<T: Protectable> Guard<T> {
 		self
 	}
 
-	pub unsafe fn inner(&self) -> &T {
+	pub(crate) unsafe fn inner(&self) -> &T {
 		&self.1
 	}
 
-	pub unsafe fn inner_mut(&mut self) -> &mut T {
+	pub(crate) unsafe fn inner_mut(&mut self) -> &mut T {
 		&mut self.1
 	}
 
-	pub fn mutate<M, R>(&mut self, mut mutation: M) -> &Self
+	pub(crate) fn mutate<M, R>(&mut self, mut mutation: M) -> &Self
 		where M: FnMut(&mut T) -> R {
 		debug_assert_eq!(self.0.swap(Self::ACC | Self::MUT, Ordering::AcqRel), 0);
 		mutation(&mut self.1);
@@ -115,12 +114,6 @@ impl<T: Protectable> Guard<T> {
 	}
 }
 
-impl<T: Protectable + Default> Default for Guard<T> {
-	fn default() -> Self {
-		Self(AtomicUsize::default(), T::default())
-	}
-}
-
 impl<T: Protectable> fmt::Debug for Guard<T> {
 	fn fmt(&self, fmt: &mut fmt::Formatter<'_>) -> fmt::Result {
 		let refs = self.0.load(Ordering::Acquire);
