@@ -4,9 +4,11 @@ use crate::guard::{Guard, Ref, RefMut};
 use crate::traits::{Pages, Protectable};
 
 use std::cmp::PartialEq;
+use std::default::Default;
+use std::mem::MaybeUninit;
 use std::ptr::NonNull;
 
-type InnerVec<T> = std::vec::Vec<T, Sensitive>;
+pub(crate) type InnerVec<T> = std::vec::Vec<T, Sensitive>;
 pub type Vec<T> = Guard<InnerVec<T>>;
 
 impl<T> Pages for InnerVec<T> {
@@ -44,7 +46,7 @@ impl<T> Vec<T> {
 		guard
 	}
 
-	fn with_capacity_unprotected(capacity: usize) -> Self {
+	pub(crate) fn with_capacity_unprotected(capacity: usize) -> Self {
 		Guard::from_inner(std::vec::Vec::with_capacity_in(capacity, Sensitive))
 	}
 
@@ -93,6 +95,12 @@ impl<T> Vec<T> {
 	}
 }
 
+impl<T> Default for Vec<T> {
+	fn default() -> Self {
+		Self::new()
+	}
+}
+
 impl<T> From<&mut [T]> for Vec<T> {
 	fn from(source: &mut [T]) -> Self {
 		let len = source.len();
@@ -168,6 +176,11 @@ impl<T, U> PartialEq<&[U]> for Ref<'_, InnerVec<T>>
 	}
 }
 
+impl<T> Ref<'_, InnerVec<T>> {
+	pub fn as_slice(&self) -> &[T] {
+		unsafe { self.0.inner() }.as_slice()
+	}
+}
 
 impl<T, U, const N: usize> PartialEq<[U; N]> for Ref<'_, InnerVec<T>>
 	where T: PartialEq<U> {
@@ -183,6 +196,14 @@ impl PartialEq<&str> for Ref<'_, InnerVec<u8>> {
 }
 
 impl<T> RefMut<'_, InnerVec<T>> {
+	pub fn as_slice(&self) -> &[T] {
+		unsafe { self.0.inner() }.as_slice()
+	}
+
+	pub fn len(&self) -> usize {
+		unsafe { self.0.inner() }.len()
+	}
+
 	pub fn push(&mut self, value: T) {
 		self.inner_mut().push(value);
 	}
@@ -194,6 +215,33 @@ impl<T> RefMut<'_, InnerVec<T>> {
 	pub fn shrink_to_fit(&mut self) {
 		self.inner_mut().shrink_to_fit();
 	}
+
+	pub fn extend<I>(&mut self, iter: I)
+		where I: IntoIterator<Item = T> {
+		self.inner_mut().extend(iter);
+	}
+
+	pub fn spare_capacity_mut(&mut self) -> &mut [MaybeUninit<T>] {
+		self.inner_mut().spare_capacity_mut()
+	}
+
+	pub fn reserve(&mut self, capacity: usize) {
+		self.inner_mut().reserve(capacity);
+	}
+
+	pub fn reserve_exact(&mut self, capacity: usize) {
+		self.inner_mut().reserve_exact(capacity);
+	}
+
+	pub unsafe fn set_len(&mut self, len: usize) {
+		self.inner_mut().set_len(len);
+	}
+}
+
+impl<T: Clone> RefMut<'_, InnerVec<T>> {
+	pub fn resize(&mut self, len: usize, value: T) {
+		self.inner_mut().resize(len, value);
+	}
 }
 
 impl<T, U> PartialEq<[U]> for RefMut<'_, InnerVec<T>>
@@ -229,7 +277,7 @@ mod tests {
 
 	#[cfg(target_os = "linux")]
 	#[test]
-	fn test_protection() {
+	fn protection() {
 		use bulletproof::Bulletproof;
 
 		let mut test = Vec::<u8>::new();
@@ -259,7 +307,7 @@ mod tests {
 	}
 
 	#[test]
-	fn test_vec_seq() {
+	fn vec_seq() {
 		const LIMIT: usize = 4194304;
 
 		let mut test: Vec<usize> = Vec::new();
@@ -282,7 +330,7 @@ mod tests {
 	}
 
 	#[test]
-	fn test_vec_rng() {
+	fn vec_rng() {
 		use rand::prelude::*;
 
 		const LIMIT: usize = 4194304;
@@ -306,7 +354,7 @@ mod tests {
 	}
 
 	#[test]
-	fn test_eq() {
+	fn eq() {
 		assert_eq!(Vec::<u8>::from(vec![]), []);
 		assert_eq!(Vec::<u8>::from(vec![0x00]), [0x00]);
 
@@ -321,8 +369,9 @@ mod tests {
 	}
 
 	#[test]
-	fn test_concurrent() {
-		use std::sync::Arc;
+	fn concurrent() {
+		use std::cmp::max;
+		use std::sync::{Arc, Barrier};
 		use std::thread;
 
 		const LIMIT: usize = 4194304;
@@ -337,24 +386,80 @@ mod tests {
 			}
 		}
 
-		let arc = Arc::new(test);
+		let concurrency = max(16, 2 * thread::available_concurrency().unwrap().get());
+		let barrier = Arc::new(Barrier::new(concurrency));
+		let vec = Arc::new(test);
+		let mut threads = std::vec::Vec::with_capacity(concurrency);
 
-		let mut jhs = std::vec::Vec::new();
+		for _ in 0..concurrency {
+			let barrier = barrier.clone();
+			let vec = vec.clone();
 
-		for _ in 0..std::cmp::min(16, 2 * thread::available_concurrency().unwrap().get()) {
-			let tref = arc.clone();
-
-			jhs.push(thread::spawn(move || {
-				let immutable = tref.borrow();
+			threads.push(thread::spawn(move || {
+				barrier.wait();
 
 				for i in 0..LIMIT {
+					let immutable = vec.borrow();
 					assert_eq!(immutable[i], i);
 				}
 			}));
 		}
 
-		for jh in jhs {
-			jh.join().unwrap();
+		for thread in threads {
+			thread.join().unwrap();
+		}
+	}
+
+	#[test]
+	fn concurrent_rw() {
+		use std::cmp::max;
+		use std::sync::{Arc, Barrier, RwLock};
+		use std::thread;
+
+		const LIMIT: usize = 32768;
+
+		let mut test: Vec<usize> = Vec::new();
+
+		{
+			let mut mutable = test.borrow_mut();
+
+			for _ in 0..LIMIT {
+				mutable.push(0);
+			}
+		}
+
+		let concurrency = max(16, 2 * thread::available_concurrency().unwrap().get());
+		let barrier = Arc::new(Barrier::new(concurrency));
+		let lock = Arc::new(RwLock::new(test));
+		let mut threads = std::vec::Vec::with_capacity(concurrency);
+
+		for _ in 0..concurrency {
+			let barrier = barrier.clone();
+			let lock = lock.clone();
+
+			threads.push(thread::spawn(move || {
+				barrier.wait();
+
+				for i in 0..LIMIT {
+					{
+						let mut vec = lock.write().unwrap();
+						let mut mutable = vec.borrow_mut();
+
+						mutable[i] = i;
+					}
+
+					{
+						let vec = lock.read().unwrap();
+						let immutable = vec.borrow();
+
+						assert_eq!(immutable[i], i);
+					}
+				}
+			}));
+		}
+
+		for thread in threads {
+			thread.join().unwrap();
 		}
 	}
 }
